<?php
/*
 * Add-on Name: Product Promo Module
 */
if ( ! class_exists( 'St_Product_Promo_Module' ) ) {
	class St_Product_Promo_Module {
		function __construct() {
			add_shortcode( 'st_product_promo_module', array( $this, 'product_promo_module_shortcode' ) );
			add_action( 'init', array( $this, 'product_promo_module_init' ) );
		}

		function product_promo_module_shortcode( $atts ) {
			$output                = $product_title = $product_subtitle = $product_img = $product_promo_layout = $product_link = '';
			$product_title_font    = $product_title_font_style = $product_title_color = $product_title_font_size = $product_title_line_height = $product_title_letter_spacing = '';
			$product_subtitle_font = $product_subtitle_font_style = $product_subtitle_color = $product_subtitle_font_size = $product_subtitle_line_height = $product_subtitle_letter_spacing = '';
			$el_class              = $module_animation = $animation = $animated = '';

			extract( shortcode_atts( array(
				'product_promo_layout'            => '',
				'product_title'                   => '',
				'product_subtitle'                => '',
				'product_img'                     => '',
				'product_link'                    => '',
				'module_animation'                => '',
				'product_title_font'              => '',
				'product_title_font_style'        => '',
				'product_title_color'             => '',
				'product_title_font_size'         => '',
				'product_title_line_height'       => '',
				'product_title_letter_spacing'    => '',
				'product_subtitle_font'           => '',
				'product_subtitle_font_style'     => '',
				'product_subtitle_color'          => '',
				'product_subtitle_font_size'      => '',
				'product_subtitle_line_height'    => '',
				'product_subtitle_letter_spacing' => '',
				'el_class'
			), $atts ) );

			// Animation TODO

			$id = uniqid( 'st-product-promo-' );

			if ( ! empty( $product_img ) ) {
				$img = apply_filters( 'ult_get_img_single', $product_img, 'url' );
				$bg  = 'style="background-image:url(' . esc_url( $img ) . ')"';
			}

			if ( empty( $product_promo_layout ) ) {
				$product_promo_layout = 'st-top-left';
			}

			$product_link_href = vc_build_link( $product_link );
			if ( $product_link_href !== '' ) {
				$product_link_target = ( $product_link_href['target'] !== '' ) ? 'target="' . esc_attr( trim( $product_link_href['target'] ) ) . '"' : '';
				$product_link_title  = ( $product_link_href['title'] !== '' ) ? 'title="' . esc_attr( $product_link_href['title'] ) . '"' : '';

				if ( ! empty( $product_link_href['rel'] ) ) {
					$rel = ' rel="' . esc_attr( $product_link_href['rel'] ) . '"';
				} else {
					$rel = '';
				}
			}

			// Title
			$product_title_style = 'style="';

			if ( $product_title_font !== '' ) {
				$product_title_font_family = function_exists( 'get_ultimate_font_family' ) ? get_ultimate_font_family( $product_title_font ) : '';
				$product_title_style       .= ! empty( $product_title_font_family ) ? 'font-family:\'' . $product_title_font_family . '\';' : '';
			}
			if ( $product_title_font_style !== '' ) {
				$product_title_style .= esc_attr( $product_title_font_style );
			}

			if ( is_numeric( $product_title_font_size ) ) {
				$product_title_font_size = 'desktop: ' . $product_title_font_size . 'px;';
			}
			if ( is_numeric( $product_title_line_height ) ) {
				$product_title_line_height = 'desktop: ' . $product_title_line_height . 'px;';
			}

			$product_title_args = array(
				'target'      => '#' . $id . ' .st-product-promo-title',
				'media_sizes' => array(
					'font-size'   => $product_title_font_size,
					'line-height' => $product_title_line_height,
				),
			);

			$product_title_responsive = get_ultimate_vc_responsive_media_css( $product_title_args );
			$product_title_style      .= $product_title_letter_spacing !== '' ? 'letter-spacing:' . esc_attr( $product_title_letter_spacing ) . 'px;' : '';
			$product_title_style      .= $product_title_color !== '' ? 'color:' . esc_attr( $product_title_color ) . ';' : '';
			$product_title_style      .= '"';

			// Subtitle
			$product_subtitle_style = 'style="';

			if ( $product_subtitle_font !== '' ) {
				$product_subtitle_font_family = function_exists( 'get_ultimate_font_family' ) ? get_ultimate_font_family( $product_subtitle_font ) : '';
				$product_subtitle_style       .= ! empty( $product_subtitle_font_family ) ? 'font-family:\'' . $product_subtitle_font_family . '\';' : '';
			}
			if ( $product_subtitle_font_style !== '' ) {
				$product_subtitle_style .= esc_attr( $product_subtitle_font_style );
			}

			if ( is_numeric( $product_subtitle_font_size ) ) {
				$product_subtitle_font_size = 'desktop: ' . $product_subtitle_font_size . 'px;';
			}
			if ( is_numeric( $product_subtitle_line_height ) ) {
				$product_subtitle_line_height = 'desktop: ' . $product_subtitle_line_height . 'px;';
			}

			$product_subtitle_args = array(
				'target'      => '#' . $id . ' .st-product-promo-subtitle',
				'media_sizes' => array(
					'font-size'   => $product_subtitle_font_size,
					'line-height' => $product_subtitle_line_height,
				),
			);

			$product_subtitle_responsive = get_ultimate_vc_responsive_media_css( $product_subtitle_args );
			$product_subtitle_style      .= $product_subtitle_letter_spacing !== '' ? 'letter-spacing:' . esc_attr( $product_subtitle_letter_spacing ) . 'px;' : '';
			$product_subtitle_style      .= $product_subtitle_color !== '' ? 'color:' . esc_attr( $product_subtitle_color ) . ';' : '';
			$product_subtitle_style      .= '"';

			$output .= '<div class="st-product-promo ' . esc_attr( $product_promo_layout ) . '" id="' . esc_attr( $id ) . '">';
			$output .= '<div class="st-product-promo-inner" ' . $bg . '>';
			if ( $product_link !== '' ) {
				$output .= '<a href="' . esc_url( $product_link_href['url'] ) . '" ' . $product_link_title . ' ' . $product_link_target . ' ' . $rel . '>';
			}
			$output .= '<div class="st-product-promo-info-wrapper">';
			$output .= '<i class="st-h-before"><i></i></i>';
			$output .= '<div class="st-product-promo-title ult-responsive" ' . $product_title_style . ' ' . $product_title_responsive . '><h3>' . esc_attr( $product_title ) . '</h3></div>';
			$output .= '<div class="st-product-promo-subtitle">' . esc_attr( $product_subtitle ) . '</div>';
			$output .= '</div>'; // st-product-promo-info-wrapper
			if ( $product_link !== '' ) {
				$output .= '</a>';
			}
			$output .= '</div>'; // st-product-promo-inner
			$output .= '</div>'; // st-product-promo

			return $output;
		}

		function product_promo_module_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'        => __( 'Product Promo', 'adamas-vc-shortcodes' ),
					'base'        => 'st_product_promo_module',
					'icon'        => get_template_directory_uri() . '/assets/images/shortcode_icons/product_promo.png',
					'category'    => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'description' => __( 'Product promo', 'adamas-vc-shortcodes' ),
					'params'      => array(
						array(
							'type'        => 'dropdown',
							'class'       => '',
							'heading'     => __( 'Title and subtitle position', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_promo_layout',
							'description' => '',
							'value'       => array(
								__( 'Top-left ', 'adamas-vc-shortcodes' )    => 'st-top-left',
								__( 'Top-right', 'adamas-vc-shortcodes' )    => 'st-top-right',
								__( 'Bottom-left ', 'adamas-vc-shortcodes' ) => 'st-bottom-left',
								__( 'Bottom-right', 'adamas-vc-shortcodes' ) => 'st-bottom-right',
							),
						),
						array(
							'type'        => 'textfield',
							'class'       => '',
							'heading'     => __( 'Title', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_title',
							'description' => '',
							'admin_label' => true,
						),
						array(
							'type'        => 'textfield',
							'class'       => '',
							'heading'     => __( 'Subtitle', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_subtitle',
							'description' => '',
						),
						array(
							'type'        => 'ult_img_single',
							'class'       => '',
							'heading'     => __( 'Image', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_img',
							'description' => '',
						),
						array(
							'type'        => 'vc_link',
							'class'       => '',
							'heading'     => __( 'Link', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_link',
							'description' => '',
						),

						// Animation
						array(
							'type'        => 'dropdown',
							'class'       => '',
							'heading'     => __( 'Animation', 'adamas-vc-shortcodes' ),
							'param_name'  => 'module_animation',
							'value'       => st_adamas_animations_list(),
							'description' => __( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
						),

						// Title typography
						array(
							'type'        => 'ultimate_google_fonts',
							'heading'     => __( 'Title font family', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_title_font',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_google_fonts_style',
							'heading'     => __( 'Title font style', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_title_font_style',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Title font color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_title_color',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_responsive',
							'class'       => 'font-size',
							'heading'     => __( 'Title font size', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_title_font_size',
							'unit'        => 'px',
							'media'       => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_responsive',
							'class'       => 'font-size',
							'heading'     => __( 'Title line height', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_title_line_height',
							'unit'        => 'px',
							'media'       => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'number',
							'heading'     => __( 'Title letter spacing', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_title_letter_spacing',
							'value'       => '',
							'description' => '',
							'suffix'      => 'px',
							'group'       => 'Typography',
						),

						// Subtitle typography
						array(
							'type'        => 'ultimate_google_fonts',
							'heading'     => __( 'Title font family', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_subtitle_font',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_google_fonts_style',
							'heading'     => __( 'Title font style', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_subtitle_font_style',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Title font color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_subtitle_color',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_responsive',
							'class'       => 'font-size',
							'heading'     => __( 'Title font size', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_subtitle_font_size',
							'unit'        => 'px',
							'media'       => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_responsive',
							'class'       => 'font-size',
							'heading'     => __( 'Title line height', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_subtitle_line_height',
							'unit'        => 'px',
							'media'       => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'number',
							'heading'     => __( 'Title letter spacing', 'adamas-vc-shortcodes' ),
							'param_name'  => 'product_subtitle_letter_spacing',
							'value'       => '',
							'description' => '',
							'suffix'      => 'px',
							'group'       => 'Typography',
						),

						array(
							'type'        => 'textfield',
							'heading'     => __( 'Extra class name', 'adamas-vc-shortcodes' ),
							'param_name'  => 'el_class',
							'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
						),
					)
				) );
			}
		}
	}

	$st_product_promo_module = new St_Product_Promo_Module;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_product_promo_module extends WPBakeryShortCode {
		}
	}
}