<?php
/**
 * Mega menu
 */

if ( ! class_exists( 'St_Adamas_Mega_Menu' ) ) {
	class St_Adamas_Mega_Menu {
		var $settings;

		/**
		 * St_Adamas_Mega_Menu constructor.
		 */
		public function __construct() {
			$this->settings = $this->menu_settings();
			$this->menu_init();
		}

		/**
		 * Class actions and filters
		 */
		private function menu_init() {
			add_filter( 'wp_setup_nav_menu_item', array( $this, 'add_menu_settings' ) );
			add_action( 'wp_update_nav_menu_item', array( $this, 'update_menu_settings' ), 10, 2 );
			add_filter( 'wp_edit_nav_menu_walker', array( $this, 'edit_walker_class' ) );
		}

		/**
		 * Menu item settings
		 *
		 * @return array
		 */
		public function menu_settings() {
			$settings = array(
				'st_adamas_wide_menu'       => array(
					'type'    => 'checkbox',
					'label'   => esc_html__( 'Wide menu', 'adamas' ),
					'default' => 0,
					'size'    => 'thin',
					'depth'   => '0',
					'class'   => 'st-adamas-wide'
				),
				'st_adamas_wide_menu_width' => array(
					'type'    => 'text',
					'label'   => esc_html__( 'Wide menu width (in px)', 'adamas' ),
					'default' => '1000',
					'size'    => 'thin',
					'depth'   => '0',
					'class'   => 'st-adamas-wide-width'
				),
				'st_adamas_columns_count'   => array(
					'type'    => 'select',
					'label'   => esc_html__( 'Wide menu columns', 'adamas' ),
					'options' => array(
						0 => esc_html__( 'None', 'adamas' ),
						1 => esc_html__( 'One', 'adamas' ),
						2 => esc_html__( 'Two', 'adamas' ),
						3 => esc_html__( 'Three', 'adamas' ),
						4 => esc_html__( 'Four', 'adamas' ),
						5 => esc_html__( 'Five', 'adamas' ),
						6 => esc_html__( 'Six', 'adamas' ),
					),
					'default' => 0,
					'size'    => 'thin',
					'depth'   => '0',
					'class'   => 'st-adamas-wide st-adamas-columns'
				),
				'st_adamas_menu_button'     => array(
					'type'    => 'checkbox',
					'label'   => esc_html__( 'Enable button', 'adamas' ),
					'default' => 0,
					'size'    => 'thin',
					'depth'   => '0',
					'class'   => 'st-adamas-button'
				),
			);

			return $settings;
		}

		/**
		 * Adding menu item setting
		 *
		 * @param $item
		 *
		 * @return mixed
		 */
		public function add_menu_settings( $item ) {
			foreach ( $this->settings as $setting => $params ) {
				$item->$setting = get_post_meta( $item->ID, $setting, true );
				if ( $item->$setting === false ) {
					$item->$setting = $params['default'];
				}
			}

			return $item;
		}

		/**
		 * Update menu item setting on save
		 *
		 * @param $menu_id
		 * @param $menu_item_id
		 */
		public function update_menu_settings( $menu_id, $menu_item_id ) {
			foreach ( $this->settings as $setting => $params ) {
				$key = 'menu-item-' . $setting;

				$setting_value = '';

				if ( isset( $_REQUEST[ $key ][ $menu_item_id ] ) ) {
					$setting_value = $_REQUEST[ $key ][ $menu_item_id ];
				}

				update_post_meta( $menu_item_id, $setting, $setting_value );
			}
		}

		/**
		 * Return walker class name
		 *
		 * @param $walker
		 *
		 * @return string
		 */
		public function edit_walker_class( $walker ) {
			return 'St_Adamas_Edit_Menu_Walker';
		}

	}
}