<?php
/*
 * Additional Theme Options
 */

// New Default Excerpt Length
function st_adamas_excerpt_length( $length ) {
	return 30;
}

// Modifying default "Read more"
function st_adamas_excerpt_more( $more ) {
	return '...';
}

// Add class to next/previous links
function st_adamas_next_posts_link_attributes() {
	return 'class="next"';
}

function st_adamas_previous_posts_link_attributes() {
	return 'class="previous"';
}

// Add prettyPhoto rel to all images
function st_adamas_autoadd_rel_prettyPhoto( $content ) {
	global $post;
	$pattern     = "/(<a(?![^>]*?rel=['\"]prettyPhoto.*)[^>]*?href=['\"][^'\"]+?\.(?:bmp|gif|jpg|jpeg|png)['\"][^\>]*)>/i";
	$replacement = '$1 rel="prettyPhoto[' . $post->ID . ']">';
	$content     = preg_replace( $pattern, $replacement, $content );

	return $content;
}

//
function st_adamas_prettyadd( $content, $id, $size, $permalink, $icon, $text ) {
	if ( $permalink ) {
		return $content;
	}
	$content = preg_replace( "/<a/", "<a rel=\"prettyPhoto[slides]\"", $content, 1 );

	return $content;
}

// Breadcrumbs author: Dimox version: 2017.21.01 license: MIT
function st_adamas_breadcrumbs() {

	global $st_adamas;

	if ( isset( $st_adamas['projects_archive'] ) && ! empty( $st_adamas['projects_archive'] ) ) {
		$projects_archive      = get_post( $st_adamas['projects_archive'] );
		$projects_archive_name = esc_attr( $projects_archive->post_title );
		$projects_archive_slug = esc_attr( $projects_archive->post_name );
	} else {
		$projects_archive_slug = 'projects';
	}

	$protocol = 'http:';
	if ( is_ssl() ) {
		$protocol = 'https:';
	}

	/* === OPTIONS === */
	$text['home']     = esc_html__( 'Home', 'adamas' ); // text for the 'Home' link
	$text['category'] = '%s'; // text for a category page
	$text['search']   = esc_html__( 'Search Results for "%s"', 'adamas' ); // text for a search results page
	$text['tag']      = esc_html__( 'Posts Tagged "%s"', 'adamas' ); // text for a tag page
	$text['author']   = esc_html__( 'Articles Posted by %s', 'adamas' ); // text for an author page
	$text['404']      = esc_html__( 'Error 404', 'adamas' ); // text for the 404 page
	$text['page']     = esc_html__( 'Page %s', 'adamas' ); // text 'Page N'
	$text['cpage']    = esc_html__( 'Comment Page %s', 'adamas' ); // text 'Comment Page N'
	$wrap_before      = '<div class="breadcrumbs" itemscope itemtype="' . $protocol . '//schema.org/BreadcrumbList">'; // the opening wrapper tag
	$wrap_after       = '</div><!-- .breadcrumbs -->'; // the closing wrapper tag
	$sep              = '›'; // separator between crumbs
	$sep_before       = '<span class="sep">'; // tag before separator
	$sep_after        = '</span>'; // tag after separator
	$show_home_link   = 1; // 1 - show the 'Home' link, 0 - don't show
	$show_on_home     = 0; // 1 - show breadcrumbs on the homepage, 0 - don't show
	$show_current     = 1; // 1 - show current page title, 0 - don't show
	$before           = '<span class="current">'; // tag before the current crumb
	$after            = '</span>'; // tag after the current crumb
	/* === END OF OPTIONS === */
	global $post;
	$home_url       = esc_url( home_url( '/' ) );
	$link_before    = '<span itemprop="itemListElement" itemscope itemtype="' . $protocol . '//schema.org/ListItem">';
	$link_after     = '</span>';
	$link_attr      = ' itemprop="item"';
	$link_in_before = '<span itemprop="name">';
	$link_in_after  = '</span>';
	$link           = $link_before . '<a href="%1$s"' . $link_attr . '>' . $link_in_before . '%2$s' . $link_in_after . '</a>' . $link_after;
	$frontpage_id   = get_option( 'page_on_front' );
	$parent_id      = ( $post ) ? $post->post_parent : '';
	$sep            = ' ' . $sep_before . $sep . $sep_after . ' ';
	$home_link      = $link_before . '<a href="' . $home_url . '"' . $link_attr . ' class="home">' . $link_in_before . $text['home'] . $link_in_after . '</a>' . $link_after;

	$link_kses        = array( 'a' => array( 'class' => array(), 'itemprop' => array(), 'href' => array() ), 'span' => array( 'itemprop' => array(), 'class' => array() ) );
	$wrap_before_kses = array( 'div' => array( 'class' => array(), 'itemscope' => array(), 'itemtype' => array() ) );
	$span_kses        = array( 'span' => array( 'itemprop' => array(), 'class' => array() ) );

	if ( is_front_page() ) {
		if ( $show_on_home ) {
			echo wp_kses( $wrap_before, $wrap_before_kses ) . $home_link . $wrap_after;
		}
	} else {
		echo wp_kses( $wrap_before, $wrap_before_kses );
		if ( $show_home_link ) {
			echo wp_kses( $home_link, $link_kses );
		}
		if ( is_home() && get_option( 'page_for_posts' ) ) {
			$page_for_posts = get_option( 'page_for_posts', true );
			if ( $page_for_posts ) {
				$blog_page_title = get_the_title( $page_for_posts );
			} else {
				esc_html_e( 'Latest Posts', 'adamas' );
			}
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}
			echo wp_kses( $before, $span_kses ) . esc_html( $blog_page_title ) . $after;
		}
		if ( is_category() ) {
			$cat = get_category( get_query_var( 'cat' ), false );
			if ( $cat->parent != 0 ) {
				$cats = get_category_parents( $cat->parent, true, $sep );
				$cats = preg_replace( "#^(.+)$sep$#", "$1", $cats );
				$cats = preg_replace( '#<a([^>]+)>([^<]+)<\/a>#', $link_before . '<a$1' . $link_attr . '>' . $link_in_before . '$2' . $link_in_after . '</a>' . $link_after, $cats );
				if ( $show_home_link ) {
					echo wp_kses( $sep, $span_kses );
				}
				echo wp_kses( $cats, $link_kses );
			}
			if ( get_query_var( 'paged' ) ) {
				$cat = $cat->cat_ID;
				echo wp_kses( $sep, $span_kses ) . sprintf( $link, get_category_link( $cat ), get_cat_name( $cat ) ) . $sep . $before . sprintf( $text['page'], get_query_var( 'paged' ) ) . $after;
			} else {
				if ( $show_current ) {
					echo wp_kses( $sep, $span_kses ) . $before . sprintf( $text['category'], single_cat_title( '', false ) ) . $after;
				}
			}
		} elseif ( is_search() ) {
			if ( have_posts() ) {
				if ( $show_home_link && $show_current ) {
					echo wp_kses( $sep, $span_kses );
				}
				if ( $show_current ) {
					echo wp_kses( $before, $span_kses ) . sprintf( $text['search'], get_search_query() ) . $after;
				}
			} else {
				if ( $show_home_link ) {
					echo wp_kses( $sep, $span_kses );
				}
				echo wp_kses( $before, $span_kses ) . sprintf( $text['search'], get_search_query() ) . $after;
			}
		} elseif ( is_day() ) {
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}
			echo sprintf( $link, get_year_link( get_the_time( 'Y' ) ), get_the_time( 'Y' ) ) . $sep;
			echo sprintf( $link, get_month_link( get_the_time( 'Y' ), get_the_time( 'm' ) ), get_the_time( 'F' ) );
			if ( $show_current ) {
				echo wp_kses( $sep, $span_kses ) . $before . get_the_time( 'd' ) . $after;
			}
		} elseif ( is_month() ) {
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}
			echo sprintf( $link, get_year_link( get_the_time( 'Y' ) ), get_the_time( 'Y' ) );
			if ( $show_current ) {
				echo wp_kses( $sep, $span_kses ) . $before . get_the_time( 'F' ) . $after;
			}
		} elseif ( is_year() ) {
			if ( $show_home_link && $show_current ) {
				echo wp_kses( $sep, $span_kses );
			}
			if ( $show_current ) {
				echo wp_kses( $before, $span_kses ) . get_the_time( 'Y' ) . $after;
			}
		} elseif ( is_single() && ! is_attachment() ) {
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}
			if ( get_post_type() === 'projects' ) {
				printf( $link, $home_url . $projects_archive_slug . '/', $projects_archive_name );
				if ( $show_current ) {
					echo wp_kses( $sep, $span_kses ) . $before . esc_html( get_the_title() ) . $after;
				}

				// WooCommerce Single Product
			} elseif ( class_exists( 'woocommerce' ) && is_product() ) {
				if ( '' !== get_option( 'woocommerce_shop_page_id' ) ) {
					$shop_id = get_option( 'woocommerce_shop_page_id' );
					printf( $link, get_permalink( $shop_id ), esc_html( get_the_title( $shop_id ) ) );
				}

				if ( $terms = wc_get_product_terms( $post->ID, 'product_cat', array(
					'orderby' => 'parent',
					'order'   => 'DESC'
				) ) ) {
					$main_term = apply_filters( 'woocommerce_breadcrumb_main_term', $terms[0], $terms );
					$ancestors = get_ancestors( $main_term->term_id, 'product_cat' );
					$ancestors = array_reverse( $ancestors );

					foreach ( $ancestors as $ancestor ) {
						$ancestor = get_term( $ancestor, 'product_cat' );
						echo wp_kses( $sep, $span_kses );
						printf( $link, get_term_link( $ancestor ), $ancestor->name );
					}
					echo wp_kses( $sep, $span_kses );
					printf( $link, get_term_link( $main_term ), $main_term->name );
				}

				if ( $show_current ) {
					echo wp_kses( $sep, $span_kses ) . $before . esc_html( get_the_title() ) . $after;
				}
			} elseif ( get_post_type() != 'post' ) {
				$post_type = get_post_type_object( get_post_type() );
				$slug      = $post_type->rewrite;
				printf( $link, $home_url . $slug['slug'] . '/', $post_type->labels->singular_name );
				if ( $show_current ) {
					echo wp_kses( $sep, $span_kses ) . $before . esc_html( get_the_title() ) . $after;
				}
			} else {
				if ( get_option( 'page_for_posts' ) ) {
					echo sprintf( $link, get_permalink( get_option( 'page_for_posts' ) ), esc_html( get_the_title( get_option( 'page_for_posts' ) ) ) ) . $sep;
				}
				$cat  = get_the_category();
				$cat  = $cat[0];
				$cats = get_category_parents( $cat, true, $sep );
				if ( ! $show_current || get_query_var( 'cpage' ) ) {
					$cats = preg_replace( "#^(.+)$sep$#", "$1", $cats );
				}
				$cats = preg_replace( '#<a([^>]+)>([^<]+)<\/a>#', $link_before . '<a$1' . $link_attr . '>' . $link_in_before . '$2' . $link_in_after . '</a>' . $link_after, $cats );
				echo wp_kses( $cats, $link_kses );
				if ( get_query_var( 'cpage' ) ) {
					echo wp_kses( $sep, $span_kses ) . sprintf( $link, get_permalink(), get_the_title() ) . $sep . $before . sprintf( $text['cpage'], get_query_var( 'cpage' ) ) . $after;
				} else {
					$title = get_the_title();
					if ( empty( $title ) ) {
						$new_title = get_the_time( get_option( 'date_format' ) );
					} else {
						$new_title = $title;
					}
					if ( $show_current ) {
						echo wp_kses( $before, $span_kses ) . esc_attr( $new_title ) . $after;
					}
				}
			}

			// WooCommerce Shop
		} elseif ( class_exists( 'woocommerce' ) && is_shop() ) {
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}
			if ( $show_current ) {
				echo wp_kses( $before, $span_kses ) . esc_html( woocommerce_page_title( false ) ) . $after;
			}
			// WooCommerce Product Category
		} elseif ( class_exists( 'woocommerce' ) && is_product_category() ) {
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}

			$shop_id = get_option( 'woocommerce_shop_page_id' );
			printf( $link, get_permalink( $shop_id ), esc_html( get_the_title( $shop_id ) ) );

			$term = get_term_by( 'slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) );

			$ancestors = get_ancestors( $term->term_id, 'product_cat' );
			$ancestors = array_reverse( $ancestors );

			foreach ( $ancestors as $ancestor ) {
				$ancestor = get_term( $ancestor, 'product_cat' );
				echo wp_kses( $sep, $span_kses );
				printf( $link, get_term_link( $ancestor ), $ancestor->name );
			}

			if ( $show_current ) {
				echo wp_kses( $sep, $span_kses ) . $before . esc_html( $term->name ) . $after;
			}
			// WooCommerce Product Tag
		} elseif ( class_exists( 'woocommerce' ) && is_product_tag() ) {
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}
			$shop_id = get_option( 'woocommerce_shop_page_id' );
			$term    = get_term_by( 'slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) );
			printf( $link, get_permalink( $shop_id ), esc_html( get_the_title( $shop_id ) ) );
			if ( $show_current ) {
				echo wp_kses( $sep, $span_kses ) . $before . sprintf( esc_html__( 'Products Tagged "%s"', 'adamas' ), esc_html( $term->name ) ) . $after;
			}
			// custom post type
		} elseif ( ! is_single() && ! is_page() && get_post_type() != 'post' && ! is_404() ) {
			$post_type = get_post_type_object( get_post_type() );
			if ( get_query_var( 'paged' ) ) {
				echo wp_kses( $sep, $span_kses ) . sprintf( $link, get_post_type_archive_link( $post_type->name ), esc_html( $post_type->label ) ) . $sep . $before . sprintf( $text['page'], esc_html( get_query_var( 'paged' ) ) ) . $after;
			} else {
				if ( $show_current ) {
					echo wp_kses( $sep, $span_kses ) . $before . esc_html( $post_type->label ) . $after;
				}
			}
		} elseif ( is_attachment() ) {
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}
			$parent = get_post( $parent_id );
			$cat    = get_the_category( $parent->ID );
			$cat    = $cat[0];
			if ( $cat ) {
				$cats = get_category_parents( $cat, true, $sep );
				$cats = preg_replace( '#<a([^>]+)>([^<]+)<\/a>#', $link_before . '<a$1' . $link_attr . '>' . $link_in_before . '$2' . $link_in_after . '</a>' . $link_after, $cats );
				echo wp_kses( $cats, $link_kses );
			}
			printf( $link, get_permalink( $parent ), $parent->post_title );
			if ( $show_current ) {
				echo wp_kses( $sep, $span_kses ) . $before . esc_html( get_the_title() ) . $after;
			}
		} elseif ( is_page() && ! $parent_id ) {
			if ( $show_current ) {
				echo wp_kses( $sep, $span_kses ) . $before . esc_html( get_the_title() ) . $after;
			}
		} elseif ( is_page() && $parent_id ) {
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}
			if ( $parent_id != $frontpage_id ) {
				$breadcrumbs = array();
				while ( $parent_id ) {
					$page = get_page( $parent_id );
					if ( $parent_id != $frontpage_id ) {
						$breadcrumbs[] = sprintf( $link, get_permalink( $page->ID ), esc_html( get_the_title( $page->ID ) ) );
					}
					$parent_id = $page->post_parent;
				}
				$breadcrumbs = array_reverse( $breadcrumbs );
				for ( $i = 0; $i < count( $breadcrumbs ); $i ++ ) {
					echo wp_kses( $breadcrumbs[ $i ], $link_kses );
					if ( $i != count( $breadcrumbs ) - 1 ) {
						echo wp_kses( $sep, $span_kses );
					}
				}
			}
			if ( $show_current ) {
				echo wp_kses( $sep, $span_kses ) . $before . esc_html( get_the_title() ) . $after;
			}
		} elseif ( is_tag() ) {
			if ( get_query_var( 'paged' ) ) {
				$tag_id = get_queried_object_id();
				$tag    = get_tag( $tag_id );
				echo wp_kses( $sep, $span_kses ) . sprintf( $link, get_tag_link( $tag_id ), esc_html( $tag->name ) ) . $sep . $before . sprintf( $text['page'], get_query_var( 'paged' ) ) . $after;
			} else {
				if ( $show_current ) {
					echo wp_kses( $sep, $span_kses ) . $before . sprintf( $text['tag'], single_tag_title( '', false ) ) . $after;
				}
			}
		} elseif ( is_author() ) {
			global $author;
			$author = get_userdata( $author );
			if ( get_query_var( 'paged' ) ) {
				if ( $show_home_link ) {
					echo wp_kses( $sep, $span_kses );
				}
				echo sprintf( $link, get_author_posts_url( $author->ID ), $author->display_name ) . $sep . $before . sprintf( $text['page'], get_query_var( 'paged' ) ) . $after;
			} else {
				if ( $show_home_link && $show_current ) {
					echo wp_kses( $sep, $span_kses );
				}
				if ( $show_current ) {
					echo wp_kses( $before, $span_kses ) . sprintf( $text['author'], esc_html( $author->display_name ) ) . $after;
				}
			}
		} elseif ( is_404() ) {
			if ( $show_home_link && $show_current ) {
				echo wp_kses( $sep, $span_kses );
			}
			if ( $show_current ) {
				echo wp_kses( $before, $span_kses ) . $text['404'] . $after;
			}
		}
		echo wp_kses( $wrap_after, $wrap_before_kses );
	}
}

// Post pagination
function st_adamas_link_pages() {
	wp_link_pages( array(
		'before'      => '<nav class="post-pagination">',
		'after'       => '</nav>',
		'link_before' => '<span>',
		'link_after'  => '</span>',
	) );
}

// Default pagination
function st_adamas_pagination() {
	global $wp_query;

	$big = 999999999;

	$paginate_links = paginate_links( array(
		'base'      => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
		'current'   => max( 1, get_query_var( 'paged' ) ),
		'total'     => $wp_query->max_num_pages,
		'mid_size'  => 2,
		'end_size'  => 2,
		'prev_text' => esc_html__( 'Previous', 'adamas' ),
		'next_text' => esc_html__( 'Next', 'adamas' ),
	) );

	if ( $paginate_links ) {
		echo '<div class="pagination">';
		echo wp_kses_post( $paginate_links );
		echo '</div>';
	}
}

// "Load more" pagination
function st_adamas_ajax_pagination() {
	global $wp_query;

	$max   = $wp_query->max_num_pages;
	$page  = get_query_var( 'paged' );
	$paged = ( $page > 1 ) ? $page : 1;

	wp_enqueue_script( 'st_adamas_blog_ajax_pagination', get_template_directory_uri() . '/assets/js/blog-ajax-pagination.js', array( 'jquery' ), false, true );

	wp_localize_script(
		'st_adamas_blog_ajax_pagination',
		'st_ajax_data',
		array(
			'startPage' => $paged,
			'maxPages'  => $max,
			'nextLink'  => next_posts( $max, false ),
			'container' => '.blog-articles',
			'loadMore'  => esc_html__( 'Load more', 'adamas' ),
			'noMore'    => esc_html__( 'No more items', 'adamas' ),
		)
	);

	echo '<div class="st-blog-load-more"><a class="load-more-button" href="#" id="st-load-more">' . esc_html__( 'Load more', 'adamas' ) . '</a><div class="st-load-more-animation"><span></span><span></span><span></span></div></div>';
}

// "lazy load" pagination
function st_adamas_lazy_pagination() {
	global $wp_query;

	$max   = $wp_query->max_num_pages;
	$page  = get_query_var( 'paged' );
	$paged = ( $page > 1 ) ? $page : 1;

	wp_enqueue_script( 'st_adamas_blog_lazy_load', get_template_directory_uri() . '/assets/js/blog-lazy-load.js', array( 'jquery' ), false, true );

	wp_localize_script(
		'st_adamas_blog_lazy_load',
		'st_ajax_data',
		array(
			'startPage' => $paged,
			'maxPages'  => $max,
			'nextLink'  => next_posts( $max, false ),
			'container' => '.blog-articles',
		)
	);

	echo '<div class="st-blog-load-more"><div class="st-load-more-animation lazy"><span></span><span></span><span></span></div></div>';
}

// Custom Search Form
function st_adamas_search_form( $form ) {
	ob_start();
	get_template_part( 'templates/searchform' );
	$form = ob_get_clean();

	return $form;
}

add_filter( 'get_search_form', 'st_adamas_search_form' );

// New tagcloud font sizes	
function st_adamas_set_tag_cloud_sizes( $args ) {
	$args['smallest'] = 10;
	$args['largest']  = 10;

	return $args;
}

add_filter( 'widget_tag_cloud_args', 'st_adamas_set_tag_cloud_sizes' );

// Allow SVG through media uploader
function st_adamas_mime_types( $mimes ) {
	$mimes['svg'] = 'image/svg+xml';

	return $mimes;
}

add_filter( 'upload_mimes', 'st_adamas_mime_types' );

// Editor style
function st_adamas_add_editor_styles() {
	global $st_adamas;
	if ( empty( $st_adamas['main_font']['font-family'] ) ) {
		$st_adamas['main_font']['font-family'] = 'Hind';
	}

	add_editor_style( get_template_directory_uri() . '/assets/css/editor-style.css' );
//	add_editor_style( $font_url );
}

add_action( 'admin_init', 'st_adamas_add_editor_styles', 999 );

// Comments template
function st_adamas_comment_template( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	?>
<li id="comment-<?php comment_ID() ?>" <?php comment_class(); ?>>
    <div class="comment-inner">
		<?php if ( get_avatar( $comment, $size = '100' ) ) { ?>
            <div class="comment-author-avatar">
				<?php echo get_avatar( $comment, $size = '100' ); ?>
            </div>
		<?php } ?>
        <div class="comment-info-inner">
            <div class="comment-author"><?php
				if ( $comment->user_id != '0' ) {
					echo get_user_meta( $comment->user_id, 'nickname', true );
				} else {
					echo get_comment_author_link();
				} ?>
            </div>
            <time class="comment-date"
                  datetime="<?php echo get_comment_date( 'Y-m-d', $comment->ID ); ?>"><?php echo get_comment_date( 'F j, Y, g:i a', $comment->ID ); ?></time>
            <div class="comment-reply">
				<?php wp_enqueue_script( 'comment-reply' ); ?>
				<?php if ( is_user_logged_in() ) : ?>
                    <span class="comment-edit">
						<?php edit_comment_link( '<span>' . esc_html__( 'Edit', 'adamas' ) . '</span>', '', '' ); ?>
                    </span>
				<?php endif; ?>
				<?php echo comment_reply_link( array(
					'depth'      => $depth,
					'max_depth'  => $args['max_depth'],
					'reply_text' => '<span>' . esc_html__( 'Leave reply', 'adamas' ) . '</span>'
				) ); ?>
            </div>
        </div>

        <div class="comment-content">
			<?php if ( $comment->comment_approved == '0' ) : ?>
                <div class="comment-alert">
					<?php esc_html_e( 'Your comment is awaiting moderation.', 'adamas' ); ?>
                </div>
			<?php endif; ?>
			<?php comment_text(); ?>
			<?php echo st_adamas_get_simple_likes_button( get_comment_ID(), 1 ); ?>
        </div>
    </div>
	<?php
}
