<?php
/*
 * Woocommerce support
 */

// Removing default plugin actions
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );
remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
remove_action( 'woocommerce_review_before', 'woocommerce_review_display_gravatar', 10 );
remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );
remove_action( 'woocommerce_checkout_terms_and_conditions', 'wc_terms_and_conditions_page_content', 30 );

// Adding custom actions
add_action( 'init', 'st_adamas_woocommerce_image_dimensions', 1 );

add_action( 'woocommerce_before_main_content', 'st_adamas_before_content', 10 );
add_action( 'woocommerce_after_main_content', 'st_adamas_after_content', 10 );

add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_link_open', 5 );
add_action( 'woocommerce_before_shop_loop_item_title', 'st_adamas_woocommerce_template_loop_product_thumbnail', 10 );
add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_link_close', 30 );
add_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_product_link_close', 15 );

add_action( 'woocommerce_before_shop_loop', 'st_adamas_sorting_wrapper', 9 );
add_action( 'woocommerce_before_shop_loop', 'st_adamas_sorting_wrapper_close', 31 );

add_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 16 );

if ( class_exists( 'YITH_WCWL' ) ) {
	add_action( 'woocommerce_after_shop_loop_item', 'st_adamas_add_to_wishlist', 17 );
}

add_action( 'woocommerce_review_before', 'st_adamas_woocommerce_review_display_gravatar', 10 );
add_action( 'st_woocommerce_cross_sell_display', 'woocommerce_cross_sell_display' );

add_action( 'woocommerce_checkout_terms_and_conditions', 'st_adamas_terms_and_conditions_page_content', 30 );

// Products per page
add_filter( 'loop_shop_per_page', function ( $cols ) {
	global $st_adamas;
	$products_per_page = isset( $st_adamas['shop_products_amount'] ) ? $st_adamas['shop_products_amount'] : '-1';

	return $products_per_page;
}, 20 );

// Column number
add_filter( 'loop_shop_columns', 'st_adamas_loop_columns' );
if ( ! function_exists( 'st_adamas_loop_columns' ) ) {
	function st_adamas_loop_columns() {
		global $st_adamas;
		$column_amount = isset( $st_adamas['shop_column_amount'] ) ? $st_adamas['shop_column_amount'] : 3;

		return $column_amount;
	}
}

// Before Content
if ( ! function_exists( 'st_adamas_before_content' ) ) {
	function st_adamas_before_content() {
		global $st_adamas;
		$shop_layout = isset( $st_adamas['shop_layout'] ) ? $st_adamas['shop_layout'] : '';

		if ( is_shop() || is_product_category() || is_product_tag() ) {
			get_template_part( 'templates/title' );
		}
		?>
        <main id="layout-container" class="shop <?php echo esc_attr( $shop_layout ); ?>">
		<?php
	}
}

// After Content
if ( ! function_exists( 'st_adamas_after_content' ) ) {
	function st_adamas_after_content() {
		?>
        </main>
		<?php
	}
}

// Sorting wrap
if ( ! function_exists( 'st_adamas_sorting_wrapper' ) ) {
	function st_adamas_sorting_wrapper() {
		echo '<div class="st-sorting">';
	}
}

// Sorting wrap close
if ( ! function_exists( 'st_adamas_sorting_wrapper_close' ) ) {
	function st_adamas_sorting_wrapper_close() {
		echo '</div>';
	}
}

// WooCommerce pagination
if ( ! function_exists( 'st_adamas_woocommerce_pagination' ) ) {
	function st_adamas_woocommerce_pagination() {
		if ( woocommerce_products_will_display() ) {
			woocommerce_pagination();
		}
	}
}

// Set new default WooCommerce image dimensions
if ( ! function_exists( 'st_adamas_woocommerce_image_dimensions' ) ) {
	function st_adamas_woocommerce_image_dimensions() {
		$catalog = array(
			'width'  => '640',    // px
			'height' => '960',    // px
			'crop'   => 1        // true
		);

		$single = array(
			'width'  => '640',    // px
			'height' => '960',    // px
			'crop'   => 1        // true
		);

		$thumbnail = array(
			'width'  => '120',    // px
			'height' => '120',    // px
			'crop'   => 1        // true
		);

		// Image sizes
		if ( get_option( 'shop_catalog_image_size' ) === false ) {
			update_option( 'shop_catalog_image_size', $catalog );        // Product category thumbs
		}
		if ( get_option( 'shop_single_image_size' ) === false ) {
			update_option( 'shop_single_image_size', $single );        // Single product image
		}
		if ( get_option( 'shop_thumbnail_image_size' ) === false ) {
			update_option( 'shop_thumbnail_image_size', $thumbnail );    // Image gallery thumbs
		}
	}
}

// Get new thumbnail
if ( ! function_exists( 'st_adamas_woocommerce_template_loop_product_thumbnail' ) ) {
	function st_adamas_woocommerce_template_loop_product_thumbnail() {
		echo st_adamas_woocommerce_get_product_thumbnail();
	}
}

// Returns product thumbnail and first image from gallery if exists
if ( ! function_exists( 'st_adamas_woocommerce_get_product_thumbnail' ) ) {
	function st_adamas_woocommerce_get_product_thumbnail( $size = 'shop_catalog' ) {
		global $post, $product, $st_adamas;
		$image_size = apply_filters( 'single_product_archive_thumbnail_size', $size );

		if ( has_post_thumbnail() ) {
			$gallery_images  = $product->get_gallery_image_ids();
			$thumbnail_props = wc_get_product_attachment_props( get_post_thumbnail_id(), $post );

			$output = '';

			if ( ! empty( $gallery_images ) && isset( $st_adamas['shop_page_hover_effect'] ) && $st_adamas['shop_page_hover_effect'] === 0 ) {
				$first_image   = ! empty( $gallery_images[0] ) ? $gallery_images[0] : '';
				$gallery_props = wc_get_product_attachment_props( $first_image, $post );

				$output .= wp_get_attachment_image( $first_image, $image_size, false, array(
					'title' => $gallery_props['title'],
					'alt'   => $gallery_props['alt'],
					'class' => 'st-products-second-thumbnail'
				) );
				$output .= get_the_post_thumbnail( $post->ID, $image_size, array(
					'title' => $thumbnail_props['title'],
					'alt'   => $thumbnail_props['alt'],
					'class' => 'st-products-first-thumbnail'
				) );
			} else {
				$output .= get_the_post_thumbnail( $post->ID, $image_size, array(
					'title' => $thumbnail_props['title'],
					'alt'   => $thumbnail_props['alt']
				) );
			}

			return $output;
		}

		if ( wc_placeholder_img_src() ) {
			return wc_placeholder_img( $image_size );
		}
	}
}

// Add to wishlist button on shop page
if ( ! function_exists( 'st_adamas_add_to_wishlist' ) ) {
	function st_adamas_add_to_wishlist() {
		echo do_shortcode( '[yith_wcwl_add_to_wishlist]' );
	}
}

// Displaying avatars in reviews
if ( ! function_exists( 'st_adamas_woocommerce_review_display_gravatar' ) ) {
	function st_adamas_woocommerce_review_display_gravatar( $comment ) {
		$GLOBALS['comment'] = $comment;
		echo get_avatar( $comment, apply_filters( 'woocommerce_review_gravatar_size', '100' ) );
	}
}

// New adress form
if ( ! function_exists( 'st_adamas_woocommerce_form_field' ) ) {
	function st_adamas_woocommerce_form_field( $key, $args, $value = null ) {
		$defaults = array(
			'type'              => 'text',
			'label'             => '',
			'description'       => '',
			'placeholder'       => '',
			'maxlength'         => false,
			'required'          => false,
			'autocomplete'      => false,
			'id'                => $key,
			'class'             => array(),
			'label_class'       => array(),
			'input_class'       => array(),
			'return'            => false,
			'options'           => array(),
			'custom_attributes' => array(),
			'validate'          => array(),
			'default'           => '',
			'autofocus'         => '',
			'priority'          => '',
		);

		$args = wp_parse_args( $args, $defaults );
		$args = apply_filters( 'woocommerce_form_field_args', $args, $key, $value );

		if ( $args['required'] ) {
			$args['class'][] = 'validate-required';
			$required        = ' <abbr class="required" title="' . esc_attr__( 'required', 'adamas' ) . '">*</abbr>';
		} else {
			$required = '';
		}

		if ( is_string( $args['label_class'] ) ) {
			$args['label_class'] = array( $args['label_class'] );
		}

		if ( $value === null ) {
			$value = $args['default'];
		}

		// Custom attribute handling
		$custom_attributes         = array();
		$args['custom_attributes'] = array_filter( (array) $args['custom_attributes'] );

		if ( $args['maxlength'] ) {
			$args['custom_attributes']['maxlength'] = absint( $args['maxlength'] );
		}

		if ( ! empty( $args['autocomplete'] ) ) {
			$args['custom_attributes']['autocomplete'] = $args['autocomplete'];
		}

		if ( true === $args['autofocus'] ) {
			$args['custom_attributes']['autofocus'] = 'autofocus';
		}

		if ( ! empty( $args['custom_attributes'] ) && is_array( $args['custom_attributes'] ) ) {
			foreach ( $args['custom_attributes'] as $attribute => $attribute_value ) {
				$custom_attributes[] = esc_attr( $attribute ) . '="' . esc_attr( $attribute_value ) . '"';
			}
		}

		if ( ! empty( $args['validate'] ) ) {
			foreach ( $args['validate'] as $validate ) {
				$args['class'][] = 'validate-' . $validate;
			}
		}

		$field           = '';
		$label_id        = $args['id'];
		$sort            = $args['priority'] ? $args['priority'] : '';
		$field_container = '<p class="form-row %1$s" id="%2$s" data-sort="' . esc_attr( $sort ) . '">%3$s</p>';

		switch ( $args['type'] ) {
			case 'country' :

				$countries = 'shipping_country' === $key ? wc()->countries->get_shipping_countries() : wc()->countries->get_allowed_countries();

				if ( 1 === sizeof( $countries ) ) {

					$field .= '<strong>' . current( array_values( $countries ) ) . '</strong>';

					$field .= '<input type="hidden" name="' . esc_attr( $key ) . '" id="' . esc_attr( $args['id'] ) . '" value="' . current( array_keys( $countries ) ) . '" ' . implode( ' ', $custom_attributes ) . ' class="country_to_state" />';

				} else {

					$field = '<select name="' . esc_attr( $key ) . '" id="' . esc_attr( $args['id'] ) . '" class="country_to_state country_select ' . esc_attr( implode( ' ', $args['input_class'] ) ) . '" ' . implode( ' ', $custom_attributes ) . '>' . '<option value="">' . esc_html__( 'Select a country&hellip;', 'adamas' ) . '</option>';

					foreach ( $countries as $ckey => $cvalue ) {
						$field .= '<option value="' . esc_attr( $ckey ) . '" ' . selected( $value, $ckey, false ) . '>' . $cvalue . '</option>';
					}

					$field .= '</select>';

					$field .= '<noscript><input type="submit" name="woocommerce_checkout_update_totals" value="' . esc_attr__( 'Update country', 'adamas' ) . '" /></noscript>';

				}

				break;
			case 'state' :

				/* Get Country */
				$country_key = 'billing_state' === $key ? 'billing_country' : 'shipping_country';
				$current_cc  = wc()->checkout->get_value( $country_key );
				$states      = wc()->countries->get_states( $current_cc );

				if ( is_array( $states ) && empty( $states ) ) {

					$field_container = '<p class="form-row %1$s" id="%2$s" style="display: none">%3$s</p>';

					$field .= '<input type="hidden" class="hidden" name="' . esc_attr( $key ) . '" id="' . esc_attr( $args['id'] ) . '" value="" ' . implode( ' ', $custom_attributes ) . ' placeholder="' . esc_attr( $args['placeholder'] ) . '" />';

				} elseif ( is_array( $states ) ) {

					$field .= '<select name="' . esc_attr( $key ) . '" id="' . esc_attr( $args['id'] ) . '" class="state_select ' . esc_attr( implode( ' ', $args['input_class'] ) ) . '" ' . implode( ' ', $custom_attributes ) . ' data-placeholder="' . esc_attr( $args['placeholder'] ) . '">
						<option value="">' . esc_html__( 'Select a state&hellip;', 'adamas' ) . '</option>';

					foreach ( $states as $ckey => $cvalue ) {
						$field .= '<option value="' . esc_attr( $ckey ) . '" ' . selected( $value, $ckey, false ) . '>' . $cvalue . '</option>';
					}

					$field .= '</select>';

				} else {

					$field .= '<input type="text" class="input-text ' . esc_attr( implode( ' ', $args['input_class'] ) ) . '" value="' . esc_attr( $value ) . '"  placeholder="' . esc_attr( $args['placeholder'] ) . '" name="' . esc_attr( $key ) . '" id="' . esc_attr( $args['id'] ) . '" ' . implode( ' ', $custom_attributes ) . ' />';

				}

				break;
			case 'textarea' :

				$field .= '<textarea name="' . esc_attr( $key ) . '" class="input-text ' . esc_attr( implode( ' ', $args['input_class'] ) ) . '" id="' . esc_attr( $args['id'] ) . '" placeholder="' . esc_attr( $args['placeholder'] ) . '" ' . ( empty( $args['custom_attributes']['rows'] ) ? ' rows="2"' : '' ) . ( empty( $args['custom_attributes']['cols'] ) ? ' cols="5"' : '' ) . implode( ' ', $custom_attributes ) . '>' . esc_textarea( $value ) . '</textarea>';

				break;
			case 'checkbox' :

				$field = '<label class="checkbox ' . implode( ' ', $args['label_class'] ) . '" ' . implode( ' ', $custom_attributes ) . '>
						<input type="' . esc_attr( $args['type'] ) . '" class="input-checkbox ' . esc_attr( implode( ' ', $args['input_class'] ) ) . '" name="' . esc_attr( $key ) . '" id="' . esc_attr( $args['id'] ) . '" value="1" ' . checked( $value, 1, false ) . ' /> '
				         . $args['label'] . $required . '</label>';

				break;
			case 'password' :
			case 'text' :
			case 'email' :
			case 'tel' :
			case 'number' :

				$field .= '<input type="' . esc_attr( $args['type'] ) . '" class="input-text ' . esc_attr( implode( ' ', $args['input_class'] ) ) . '" name="' . esc_attr( $key ) . '" id="' . esc_attr( $args['id'] ) . '" placeholder="' . esc_attr( $args['label'] ) . '"  value="' . esc_attr( $value ) . '" ' . implode( ' ', $custom_attributes ) . ' />';

				break;
			case 'select' :

				$options = $field = '';

				if ( ! empty( $args['options'] ) ) {
					foreach ( $args['options'] as $option_key => $option_text ) {
						if ( '' === $option_key ) {
							// If we have a blank option, select2 needs a placeholder
							if ( empty( $args['placeholder'] ) ) {
								$args['placeholder'] = $option_text ? $option_text : __( 'Choose an option', 'adamas' );
							}
							$custom_attributes[] = 'data-allow_clear="true"';
						}
						$options .= '<option value="' . esc_attr( $option_key ) . '" ' . selected( $value, $option_key, false ) . '>' . esc_attr( $option_text ) . '</option>';
					}

					$field .= '<select name="' . esc_attr( $key ) . '" id="' . esc_attr( $args['id'] ) . '" class="select ' . esc_attr( implode( ' ', $args['input_class'] ) ) . '" ' . implode( ' ', $custom_attributes ) . ' data-placeholder="' . esc_attr( $args['placeholder'] ) . '">
							' . $options . '
						</select>';
				}

				break;
			case 'radio' :

				$label_id = current( array_keys( $args['options'] ) );

				if ( ! empty( $args['options'] ) ) {
					foreach ( $args['options'] as $option_key => $option_text ) {
						$field .= '<input type="radio" class="input-radio ' . esc_attr( implode( ' ', $args['input_class'] ) ) . '" value="' . esc_attr( $option_key ) . '" name="' . esc_attr( $key ) . '" id="' . esc_attr( $args['id'] ) . '_' . esc_attr( $option_key ) . '"' . checked( $value, $option_key, false ) . ' />';
						$field .= '<label for="' . esc_attr( $args['id'] ) . '_' . esc_attr( $option_key ) . '" class="radio ' . implode( ' ', $args['label_class'] ) . '">' . $option_text . '</label>';
					}
				}

				break;
		}

		if ( ! empty( $field ) ) {
			$field_html = '';

			if ( $args['label'] && 'checkbox' !== $args['type'] ) {
				$field_html .= '<label for="' . esc_attr( $label_id ) . '" class="' . esc_attr( implode( ' ', $args['label_class'] ) ) . '">' . $args['label'] . $required . '</label>';
			}

			$field_html .= $field;

			if ( $args['description'] ) {
				$field_html .= '<span class="description">' . esc_html( $args['description'] ) . '</span>';
			}

			$container_class = esc_attr( implode( ' ', $args['class'] ) );
			$container_id    = esc_attr( $args['id'] ) . '_field';
			$field           = sprintf( $field_container, $container_class, $container_id, $field_html );
		}

		$field = apply_filters( 'woocommerce_form_field_' . $args['type'], $field, $key, $args, $value );

		if ( $args['return'] ) {
			return $field;
		}

		echo ! empty( $field ) ? $field : '';

	}
}

// Clear cart button
add_action( 'init', 'st_adamas_clear_cart' );

if ( ! function_exists( 'st_adamas_clear_cart' ) ) {
	function st_adamas_clear_cart() {
		global $woocommerce;
		if ( isset ( $_REQUEST['clear_cart'] ) ) {
			$woocommerce->cart->empty_cart();
		}
	}
}

// Ensure cart contents update when products are added to the cart via AJAX
add_filter( 'woocommerce_add_to_cart_fragments', 'st_adamas_woocommerce_header_add_to_cart_fragment' );

function st_adamas_woocommerce_header_add_to_cart_fragment( $fragments ) {
	global $woocommerce;

	ob_start();

	if ( ! ( $woocommerce->cart->cart_contents_count == '0' ) ) { ?>
        <div class="st-cart-count products-in-cart"><?php echo esc_attr( $woocommerce->cart->cart_contents_count ); ?></div>
	<?php } else { ?>
        <div class="st-cart-count"></div>
	<?php }

	$fragments['div.st-cart-count'] = ob_get_clean();

	return $fragments;

}

function st_adamas_terms_and_conditions_page_content() {
	$terms_page_id = wc_terms_and_conditions_page_id();

	if ( ! $terms_page_id ) {
		return;
	}

	$page = get_post( $terms_page_id );

	if ( $page && 'publish' === $page->post_status && $page->post_content && ! has_shortcode( $page->post_content, 'woocommerce_checkout' ) ) {
		$page_content = strip_shortcodes( st_adamas_remove_vc_shortcodes( $page->post_content ) );
		echo '<div class="woocommerce-terms-and-conditions" style="display: none; max-height: 200px; overflow: auto;">' . wp_kses_post( wc_format_content( $page_content ) ) . '</div>';
	}
}

add_filter( 'woocommerce_rating_filter_count', 'st_adamas_widget_rating_filter', 10, 1 );

function st_adamas_widget_rating_filter( $count_string ) {

	return '<span>' . $count_string . '</span>';

}

// Enabling product gallery features WooCommerce 3.0.0
add_theme_support( 'wc-product-gallery-zoom' );
add_theme_support( 'wc-product-gallery-lightbox' );
add_theme_support( 'wc-product-gallery-slider' );