<?php
/**
 * Pagination - Show numbered pagination for catalog pages
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/loop/pagination.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see        https://docs.woocommerce.com/document/template-structure/
 * @author        WooThemes
 * @package    WooCommerce/Templates
 * @version     3.3.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $wp_query, $st_adamas;

$shop_page_pagination = isset( $st_adamas['shop_page_pagination'] ) ? $st_adamas['shop_page_pagination'] : 'standard';
$total                = isset( $total ) ? $total : wc_get_loop_prop( 'total_pages' );
$current              = isset( $current ) ? $current : wc_get_loop_prop( 'current_page' );
$base                 = isset( $base ) ? $base : esc_url_raw( str_replace( 999999999, '%#%', remove_query_arg( 'add-to-cart', get_pagenum_link( 999999999, false ) ) ) );
$format               = isset( $format ) ? $format : '';

if ( $wp_query->max_num_pages <= 1 ) {
	return;
}
?>
<?php if ( $shop_page_pagination == 'standard' || $shop_page_pagination == 'ajax' || $shop_page_pagination == 'lazy' ) { ?>
    <nav class="woocommerce-pagination">
		<?php
		if ( $shop_page_pagination == 'standard' ) {
			$woocommerce_paginate_links = paginate_links( apply_filters( 'woocommerce_pagination_args', array(
				'base'      => $base,
				'format'    => $format,
				'add_args'  => false,
				'current'   => max( 1, $current ),
				'total'     => $total,
				'prev_text' => esc_html__( 'Previous', 'adamas' ),
				'next_text' => esc_html__( 'Next', 'adamas' ),
				'end_size'  => 2,
				'mid_size'  => 2
			) ) );

			if ( $woocommerce_paginate_links ) {
				echo '<div class="pagination">';
				echo wp_kses_post( $woocommerce_paginate_links );
				echo '</div>';
			}
		} elseif ( $shop_page_pagination == 'ajax' ) {
			$max   = $wp_query->max_num_pages;
			$page  = get_query_var( 'paged' );
			$paged = ( $page > 1 ) ? $page : 1;

			wp_enqueue_script( 'st_adamas_shop_ajax_pagination', get_template_directory_uri() . '/assets/js/shop-ajax-pagination.js', array( 'jquery' ), false, true );

			wp_localize_script(
				'st_adamas_shop_ajax_pagination',
				'st_ajax_data',
				array(
					'startPage' => $paged,
					'maxPages'  => $max,
					'nextLink'  => next_posts( $max, false ),
					'container' => '.st-product-list',
					'loadMore'  => esc_html__( 'Load more', 'adamas' ),
					'noMore'    => esc_html__( 'No more items', 'adamas' ),
				)
			);

			echo '<div class="st-shop-load-more"><a class="load-more-button" href="#" id="st-load-more">' . esc_html__( 'Load more', 'adamas' ) . '</a><div class="st-load-more-animation"><span></span><span></span><span></span></div></div>';
		} else {
			$max   = $wp_query->max_num_pages;
			$page  = get_query_var( 'paged' );
			$paged = ( $page > 1 ) ? $page : 1;

			wp_enqueue_script( 'st_adamas_shop_lazy_load', get_template_directory_uri() . '/assets/js/shop-lazy-load.js', array( 'jquery' ), false, true );

			wp_localize_script(
				'st_adamas_shop_lazy_load',
				'st_ajax_data',
				array(
					'startPage' => $paged,
					'maxPages'  => $max,
					'nextLink'  => next_posts( $max, false ),
					'container' => '.st-product-list',
				)
			);

			echo '<div class="st-shop-load-more"><div class="st-load-more-animation lazy"><span></span><span></span><span></span></div></div>';
		}
		?>
    </nav>
<?php } ?>